######################
django-jqchat 
######################

A chat client for `Django <http://www.djangoproject.com/>`_ using the `jQuery <http://www.jquery.com/>`_ library.

`Try out the demo <http://arbee-design.co.uk/jqchat/room/1/>`_

*************
Extensible
*************

django-jqchat is designed to work in situations where the
chat window is not the only data to be updated by Ajax
calls. It allows extra data to be piggybacked on the
Ajax payloads; for an example, see
`this demo <http://arbee-design.co.uk/jqchat/room_with_description/1/>`_
where a description field can be updated by the user.

